==> auth-2.3.0911.7-sources.jar: com/zing/zalo/zalosdk/auth/internal/d.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnDismissListener;
import android.os.Bundle;
import android.os.Handler;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.core.log.Log;

public class d extends c implements OnDismissListener {
    String a = d.class.getSimpleName();
    String b;
    String c;
    String d;
    String e;
    String f;
    public boolean g = false;
    boolean h = false;
    int i = 0;
    Handler j = new Handler();
    Runnable k = new Runnable(this) {
        final /* synthetic */ d a;

        {
            this.a = r1;
        }

        public final void run() {
            if (this.a.i > 0 && this.a.isShowing()) {
                this.a.b();
                if (this.a.n != null) {
                    this.a.n.onClose();
                }
            }
        }
    };
    Runnable l = new Runnable(this) {
        final /* synthetic */ d a;

        {
            this.a = r1;
        }

        public final void run() {
            if (this.a.g) {
                d dVar = this.a;
                ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(this.a.f);
            }
        }
    };
    Runnable m = new Runnable(this) {
        final /* synthetic */ d a;

        {
            this.a = r1;
        }

        public final void run() {
            Log.i("THREAD START", "time out " + this.a.g + " " + this.a.i);
            if (this.a.g && this.a.i == 0) {
                this.a.b();
                d dVar = this.a;
                int i = b.TIMEOUT$5a1610ce;
                dVar.show();
                dVar.g = true;
                ImageView imageView;
                switch (AnonymousClass4.a[i - 1]) {
                    case 1:
                        Log.i("THREAD BEGIN", "PROCESSING!!");
                        ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(dVar.b);
                        dVar.findViewById(R.id.zalosdk_status_ctl).setVisibility(8);
                        dVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(0);
                        dVar.setCancelable(false);
                        dVar.i = 0;
                        return;
                    case 2:
                        Log.i(dVar.a, "Show success dialog");
                        ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(dVar.c);
                        dVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) dVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_success);
                        imageView.setVisibility(0);
                        dVar.setCancelable(true);
                        dVar.i = 1;
                        dVar.a();
                        return;
                    case 3:
                        ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(dVar.d);
                        dVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) dVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_fail);
                        imageView.setVisibility(0);
                        dVar.setCancelable(true);
                        dVar.i = 1;
                        dVar.a();
                        return;
                    case 4:
                        Log.i("debuglog", "time out showview");
                        dVar.findViewById(R.id.zalosdk_process_dialog_ctl).setVisibility(8);
                        dVar.setCancelable(true);
                        dVar.i = 1;
                        dVar.j.postDelayed(dVar.k, 1);
                        dVar.h = true;
                        return;
                    default:
                        return;
                }
            }
        }
    };
    a n;

    static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] a = new int[b.a().length];

        static {
            try {
                a[b.PROCESSING$5a1610ce - 1] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                a[b.SUCCESS$5a1610ce - 1] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                a[b.FAILED$5a1610ce - 1] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                a[b.TIMEOUT$5a1610ce - 1] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public interface a {
        void onClose();
    }

    public enum b {
        ;
        
        public static final int FAILED$5a1610ce = 0;
        public static final int PROCESSING$5a1610ce = 0;
        public static final int SUCCESS$5a1610ce = 0;
        public static final int TIMEOUT$5a1610ce = 0;

        static {
            PROCESSING$5a1610ce = 1;
            SUCCESS$5a1610ce = 2;
            FAILED$5a1610ce = 3;
            TIMEOUT$5a1610ce = 4;
            $VALUES$ad1396d = new int[]{PROCESSING$5a1610ce, SUCCESS$5a1610ce, FAILED$5a1610ce, TIMEOUT$5a1610ce};
        }

        public static int[] a() {
            return (int[]) $VALUES$ad1396d.clone();
        }
    }

    public d(Context context, a aVar) {
        super(context);
        this.n = aVar;
        setOnDismissListener(this);
        this.b = s.a("zalosdk_processing");
        this.c = s.a("zalosdk_success");
        this.d = s.a("zalosdk_unsuccess");
        this.e = s.a("zalosdk_atm_processing");
        this.f = s.a("zalosdk_atm_processing_waiting");
    }

    final void a() {
        this.j.postDelayed(this.k, 3000);
    }

    public final void b() {
        this.g = false;
        hide();
    }

    public void hide() {
        Log.i(this.a, "hide loading!");
        super.hide();
    }

    public void onBackPressed() {
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView(R.layout.zalosdk_activity_processing);
    }

    public void onDismiss(DialogInterface dialogInterface) {
        if (this.n != null) {
            Log.i(getClass().getName(), "cancel");
            this.n.onClose();
        }
    }

    public void show() {
        Log.i(this.a, "show loading..");
        try {
            super.show();
        } catch (Exception e) {
            Log.i(this.a, "error can not show loading");
        }
    }
}

==> auth-2.3.0920-sources.jar: com/zing/zalo/zalosdk/auth/internal/d.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnDismissListener;
import android.os.Bundle;
import android.os.Handler;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.core.log.Log;

public class d extends c implements OnDismissListener {
    String a = d.class.getSimpleName();
    String b;
    String c;
    String d;
    String e;
    String f;
    public boolean g = false;
    boolean h = false;
    int i = 0;
    Handler j = new Handler();
    Runnable k = new Runnable(this) {
        final /* synthetic */ d a;

        {
            this.a = r1;
        }

        public final void run() {
            if (this.a.i > 0 && this.a.isShowing()) {
                this.a.b();
                if (this.a.n != null) {
                    this.a.n.onClose();
                }
            }
        }
    };
    Runnable l = new Runnable(this) {
        final /* synthetic */ d a;

        {
            this.a = r1;
        }

        public final void run() {
            if (this.a.g) {
                d dVar = this.a;
                ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(this.a.f);
            }
        }
    };
    Runnable m = new Runnable(this) {
        final /* synthetic */ d a;

        {
            this.a = r1;
        }

        public final void run() {
            Log.i("THREAD START", "time out " + this.a.g + " " + this.a.i);
            if (this.a.g && this.a.i == 0) {
                this.a.b();
                d dVar = this.a;
                int i = b.TIMEOUT$5a1610ce;
                dVar.show();
                dVar.g = true;
                ImageView imageView;
                switch (AnonymousClass4.a[i - 1]) {
                    case 1:
                        Log.i("THREAD BEGIN", "PROCESSING!!");
                        ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(dVar.b);
                        dVar.findViewById(R.id.zalosdk_status_ctl).setVisibility(8);
                        dVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(0);
                        dVar.setCancelable(false);
                        dVar.i = 0;
                        return;
                    case 2:
                        Log.i(dVar.a, "Show success dialog");
                        ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(dVar.c);
                        dVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) dVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_success);
                        imageView.setVisibility(0);
                        dVar.setCancelable(true);
                        dVar.i = 1;
                        dVar.a();
                        return;
                    case 3:
                        ((TextView) dVar.findViewById(R.id.zalosdk_message_ctl)).setText(dVar.d);
                        dVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) dVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_fail);
                        imageView.setVisibility(0);
                        dVar.setCancelable(true);
                        dVar.i = 1;
                        dVar.a();
                        return;
                    case 4:
                        Log.i("debuglog", "time out showview");
                        dVar.findViewById(R.id.zalosdk_process_dialog_ctl).setVisibility(8);
                        dVar.setCancelable(true);
                        dVar.i = 1;
                        dVar.j.postDelayed(dVar.k, 1);
                        dVar.h = true;
                        return;
                    default:
                        return;
                }
            }
        }
    };
    a n;

    static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] a = new int[b.a().length];

        static {
            try {
                a[b.PROCESSING$5a1610ce - 1] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                a[b.SUCCESS$5a1610ce - 1] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                a[b.FAILED$5a1610ce - 1] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                a[b.TIMEOUT$5a1610ce - 1] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public interface a {
        void onClose();
    }

    public enum b {
        ;
        
        public static final int FAILED$5a1610ce = 0;
        public static final int PROCESSING$5a1610ce = 0;
        public static final int SUCCESS$5a1610ce = 0;
        public static final int TIMEOUT$5a1610ce = 0;

        static {
            PROCESSING$5a1610ce = 1;
            SUCCESS$5a1610ce = 2;
            FAILED$5a1610ce = 3;
            TIMEOUT$5a1610ce = 4;
            $VALUES$ad1396d = new int[]{PROCESSING$5a1610ce, SUCCESS$5a1610ce, FAILED$5a1610ce, TIMEOUT$5a1610ce};
        }

        public static int[] a() {
            return (int[]) $VALUES$ad1396d.clone();
        }
    }

    public d(Context context, a aVar) {
        super(context);
        this.n = aVar;
        setOnDismissListener(this);
        this.b = l.a("zalosdk_processing");
        this.c = l.a("zalosdk_success");
        this.d = l.a("zalosdk_unsuccess");
        this.e = l.a("zalosdk_atm_processing");
        this.f = l.a("zalosdk_atm_processing_waiting");
    }

    final void a() {
        this.j.postDelayed(this.k, 3000);
    }

    public final void b() {
        this.g = false;
        hide();
    }

    public void hide() {
        Log.i(this.a, "hide loading!");
        super.hide();
    }

    public void onBackPressed() {
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView(R.layout.zalosdk_activity_processing);
    }

    public void onDismiss(DialogInterface dialogInterface) {
        if (this.n != null) {
            Log.i(getClass().getName(), "cancel");
            this.n.onClose();
        }
    }

    public void show() {
        Log.i(this.a, "show loading..");
        try {
            super.show();
        } catch (Exception e) {
            Log.i(this.a, "error can not show loading");
        }
    }
}
